@@ -13,22 +13,12 @@
 
 #include <Akonadi/ServerManager>
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <Kdelibs4ConfigMigrator>
-#endif
-
 #include <KWindowSystem>
 #include <QDBusConnection>
 
 NotesAgent::NotesAgent(const QString &id)
     : Akonadi::AgentBase(id)
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    Kdelibs4ConfigMigrator migrate(QStringLiteral("notesagent"));
-    migrate.setConfigFiles(QStringList() << QStringLiteral("akonadi_notes_agentrc") << QStringLiteral("akonadi_notes_agent.notifyrc"));
-    migrate.migrate();
-#endif
-
     mNotesManager = new NotesManager(this);
     new NotesAgentAdaptor(this);
     QDBusConnection::sessionBus().registerObject(QStringLiteral("/NotesAgent"), this, QDBusConnection::ExportAdaptors);
@@ -165,3 +155,5 @@ int NotesAgent::alarmCheckInterval() const
 }
 
 AKONADI_AGENT_MAIN(NotesAgent)
+
+#include "moc_notesagent.cpp"
