@@ -8,8 +8,8 @@
 #include "notesagent_debug.h"
 #include <Akonadi/ItemFetchJob>
 #include <Akonadi/ItemFetchScope>
-#include <KPIMTextEdit/RichTextEditor>
-#include <KPIMTextEdit/RichTextEditorWidget>
+#include <TextCustomEditor/RichTextEditor>
+#include <TextCustomEditor/RichTextEditorWidget>
 
 #include <KSharedConfig>
 
@@ -31,7 +31,7 @@ static const char myNotesAgentNoteDialogName[] = "NotesAgentNoteDialog";
 }
 NotesAgentNoteDialog::NotesAgentNoteDialog(QWidget *parent)
     : QDialog(parent)
-    , mNote(new KPIMTextEdit::RichTextEditorWidget(this))
+    , mNote(new TextCustomEditor::RichTextEditorWidget(this))
     , mSubject(new QLineEdit(this))
 {
     auto mainLayout = new QVBoxLayout(this);
@@ -103,14 +103,16 @@ void NotesAgentNoteDialog::readConfig()
 {
     create(); // ensure a window is created
     windowHandle()->resize(QSize(300, 200));
-    KConfigGroup group(KSharedConfig::openStateConfig(), myNotesAgentNoteDialogName);
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myNotesAgentNoteDialogName));
     KWindowConfig::restoreWindowSize(windowHandle(), group);
     resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void NotesAgentNoteDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), myNotesAgentNoteDialogName);
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myNotesAgentNoteDialogName));
     KWindowConfig::saveWindowSize(windowHandle(), group);
     group.sync();
 }
+
+#include "moc_notesagentnotedialog.cpp"
