@@ -24,7 +24,7 @@ NoteNetworkConfigWidget::NoteNetworkConfigWidget(QWidget *parent)
     : QWidget(parent)
 {
     auto layout = new QVBoxLayout(this);
-    layout->setContentsMargins(0, 0, 0, 0);
+    // layout->setContentsMargins(0, 0, 0, 0);
 
     auto incoming = new QGroupBox(i18n("Incoming Notes"));
     auto tmpLayout = new QHBoxLayout;
@@ -81,24 +81,12 @@ void NoteNetworkConfigWidget::load()
     kcfg_Port->setValue(NoteShared::NoteSharedGlobalConfig::self()->port());
 }
 
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-NoteNetworkConfig::NoteNetworkConfig(QWidget *parent, const QVariantList &args)
-    : KCModule(parent, args)
-#else
-NoteNetworkConfig::NoteNetworkConfig(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
-    : KCModule(parent, data, args)
-#endif
+NoteNetworkConfig::NoteNetworkConfig(QObject *parent, const KPluginMetaData &data)
+    : KCModule(parent, data)
 {
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    auto lay = new QVBoxLayout(this);
-    lay->setContentsMargins(0, 0, 0, 0);
-    auto noteNetworkConfigWidget = new NoteNetworkConfigWidget(this);
-#else
     auto lay = new QVBoxLayout(widget());
     lay->setContentsMargins(0, 0, 0, 0);
     auto noteNetworkConfigWidget = new NoteNetworkConfigWidget(widget());
-
-#endif
     lay->addWidget(noteNetworkConfigWidget);
     addConfig(NoteShared::NoteSharedGlobalConfig::self(), noteNetworkConfigWidget);
     load();
@@ -113,3 +101,5 @@ void NoteNetworkConfig::load()
 {
     KCModule::load();
 }
+
+#include "moc_notenetworkconfig.cpp"
