@@ -85,14 +85,16 @@ void KNoteSelectedNotesDialog::readConfig()
 {
     create(); // ensure a window is created
     windowHandle()->resize(QSize(300, 200));
-    KConfigGroup group(KSharedConfig::openStateConfig(), myKNoteSelectedNotesDialogName);
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myKNoteSelectedNotesDialogName));
     KWindowConfig::restoreWindowSize(windowHandle(), group);
     resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void KNoteSelectedNotesDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), myKNoteSelectedNotesDialogName);
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myKNoteSelectedNotesDialogName));
     KWindowConfig::saveWindowSize(windowHandle(), group);
     group.sync();
 }
+
+#include "moc_knoteselectednotesdialog.cpp"
