@@ -48,14 +48,14 @@ void KNotesKeyDialog::readConfig()
 {
     create(); // ensure a window is created
     windowHandle()->resize(QSize(300, 200));
-    KConfigGroup group(KSharedConfig::openStateConfig(), myKNotesKeyDialogName);
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myKNotesKeyDialogName));
     KWindowConfig::restoreWindowSize(windowHandle(), group);
     resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void KNotesKeyDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), myKNotesKeyDialogName);
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myKNotesKeyDialogName));
     KWindowConfig::saveWindowSize(windowHandle(), group);
     group.sync();
 }
