@@ -7,6 +7,8 @@
 #include "config-knotes.h"
 #include "widget/notelistwidget.h"
 
+#include <TextUtils/ConvertText>
+
 #include <PIM/notequery.h>
 #include <PIM/resultiterator.h>
 
@@ -25,9 +27,7 @@
 #include <QVBoxLayout>
 #include <QWindow>
 
-#if KDEPIM_HAVE_TEXT_ADDONS_WIDGETS_SUPPORT
-#include <TextAddonsWidgets/LineEditCatchReturnKey>
-#endif
+#include <KLineEditEventHandler>
 
 KNoteFindDialog::KNoteFindDialog(QWidget *parent)
     : QDialog(parent)
@@ -62,14 +62,14 @@ void KNoteFindDialog::readConfig()
 {
     create(); // ensure a window is created
     windowHandle()->resize(QSize(600, 300));
-    KConfigGroup group(KSharedConfig::openStateConfig(), myKNoteFindDialogName);
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myKNoteFindDialogName));
     KWindowConfig::restoreWindowSize(windowHandle(), group);
     resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void KNoteFindDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), myKNoteFindDialogName);
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myKNoteFindDialogName));
     KWindowConfig::saveWindowSize(windowHandle(), group);
     group.sync();
 }
@@ -88,9 +88,7 @@ KNoteFindWidget::KNoteFindWidget(QWidget *parent)
     auto lab = new QLabel(i18nc("@label:textbox", "Search notes:"), this);
     hbox->addWidget(lab);
     mSearchLineEdit->setClearButtonEnabled(true);
-#if KDEPIM_HAVE_TEXT_ADDONS_WIDGETS_SUPPORT
-    new TextAddonsWidgets::LineEditCatchReturnKey(mSearchLineEdit, this);
-#endif
+    KLineEditEventHandler::catchReturnKey(mSearchLineEdit);
     connect(mSearchLineEdit, &QLineEdit::returnPressed, this, &KNoteFindWidget::slotSearchNote);
     connect(mSearchLineEdit, &QLineEdit::textChanged, this, &KNoteFindWidget::slotTextChanged);
     hbox->addWidget(mSearchLineEdit);
@@ -124,33 +122,6 @@ void KNoteFindWidget::slotItemDoubleClicked(QListWidgetItem *item)
     Q_EMIT noteSelected(mNoteList->itemId(item));
 }
 
-// code from kitinerary/src/lib/stringutil.cpp
-static QString normalize(QStringView str)
-{
-    QString out;
-    out.reserve(str.size());
-    for (const auto c : str) {
-        // case folding
-        const auto n = c.toCaseFolded();
-
-        // if the character has a canonical decomposition use that and skip the
-        // combining diacritic markers following it
-        // see https://en.wikipedia.org/wiki/Unicode_equivalence
-        // see https://en.wikipedia.org/wiki/Combining_character
-        if (n.decompositionTag() == QChar::Canonical) {
-            out.push_back(n.decomposition().at(0));
-        }
-        // handle compatibility compositions such as ligatures
-        // see https://en.wikipedia.org/wiki/Unicode_compatibility_characters
-        else if (n.decompositionTag() == QChar::Compat && n.isLetter() && n.script() == QChar::Script_Latin) {
-            out.append(n.decomposition());
-        } else {
-            out.push_back(n);
-        }
-    }
-    return out;
-}
-
 void KNoteFindWidget::slotSearchNote()
 {
     const QString searchStr = mSearchLineEdit->text().trimmed();
@@ -158,9 +129,9 @@ void KNoteFindWidget::slotSearchNote()
         return;
     }
     auto config = KConfig(QStringLiteral("akonadi_indexing_agent"));
-    KConfigGroup cfg = config.group("General");
+    KConfigGroup cfg = config.group(QStringLiteral("General"));
     const bool respectDiacriticAndAccents = cfg.readEntry("respectDiacriticAndAccents", true);
-    const QString searchString = respectDiacriticAndAccents ? searchStr : normalize(searchStr);
+    const QString searchString = respectDiacriticAndAccents ? searchStr : TextUtils::ConvertText::normalize(searchStr);
     Akonadi::Search::PIM::NoteQuery query;
     query.matchNote(searchString);
     query.matchTitle(searchString);
@@ -198,3 +169,5 @@ void KNoteFindWidget::customContextMenuRequested(const QPoint &)
         menu.exec(QCursor::pos());
     }
 }
+
+#include "moc_knotefinddialog.cpp"
