@@ -193,7 +193,7 @@ KNotesPart::KNotesPart(QObject *parent)
 
     KSharedConfigPtr _config = KSharedConfig::openConfig(QStringLiteral("kcmknotessummaryrc"));
 
-    mModelState = new KViewStateMaintainer<Akonadi::ETMViewStateSaver>(_config->group("CheckState"), this);
+    mModelState = new KViewStateMaintainer<Akonadi::ETMViewStateSaver>(_config->group(QStringLiteral("CheckState")), this);
     mModelState->setSelectionModel(mSelectionModel);
 
     mNotesWidget = new KNotesWidget(this, widget());
@@ -831,3 +831,5 @@ void KNotesPart::slotNewNoteFromTextFile()
         newNote(i18n("Note from file '%1'", filename), text);
     }
 }
+
+#include "moc_knotes_part.cpp"
