@@ -125,14 +125,14 @@ void KNoteEditDialog::readConfig()
 {
     create(); // ensure a window is created
     windowHandle()->resize(QSize(300, 200));
-    KConfigGroup group(KSharedConfig::openStateConfig(), myKNoteEditDialogName);
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myKNoteEditDialogName));
     KWindowConfig::restoreWindowSize(windowHandle(), group);
     resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void KNoteEditDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), myKNoteEditDialogName);
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myKNoteEditDialogName));
     KWindowConfig::saveWindowSize(windowHandle(), group);
     group.sync();
 }
@@ -196,3 +196,5 @@ int KNoteEditDialog::cursorPositionFromStart() const
 {
     return mNoteEdit->cursorPositionFromStart();
 }
+
+#include "moc_knoteseditdialog.cpp"
